@@ -12,7 +12,7 @@
 #' @param mode signature type for plotting, now supports 'copynumber', 'SBS',
 #' 'DBS', 'ID' and 'RS' (genome rearrangement signature).
 #' @param method method for copy number feature classification in [sig_tally],
-#' can be one of "Macintyre" ("M"), "Wang" ("W").
+#' can be one of "Wang" ("W"), "S".
 #' @param by_context for specific use.
 #' @param normalize one of 'row', 'column', 'raw' and "feature", for row normalization (signature),
 #' column normalization (component), raw data, row normalization by feature, respectively.
@@ -25,7 +25,6 @@
 #' default use a built-in palette according to parameter `style`.
 #' @param set_gradient_color default is `FALSE`, if `TRUE`, use gradient colors
 #' to fill bars.
-#' **This is very useful when signatures are extracted from "Macintyre" method and `normalize` is 'column'.**
 #' @param free_space default is 'free_x'. If "fixed", all panels have the same size.
 #' If "free_y" their height will be proportional to the length of the y scale;
 #' if "free_x" their width will be proportional to the length of the x scale;
@@ -91,47 +90,17 @@
 #' )
 #' p2
 #'
-#' # Load copy number signature from method "M"
-#' load(system.file("extdata", "toy_copynumber_signature_by_M.RData",
-#'   package = "sigminer", mustWork = TRUE
-#' ))
-#' # Show signature profile
-#' # The 'column' normalization is consistent with
-#' # original paper
-#' p3 <- show_sig_profile(sig,
-#'   paint_axis_text = FALSE,
-#'   mode = "copynumber",
-#'   method = "M", normalize = "column"
-#' )
-#' p3
-#'
-#' # Add params label
-#' # =================
-#' # Load copy number prepare object
-#' load(system.file("extdata", "toy_copynumber_tally_M.RData",
-#'   package = "sigminer", mustWork = TRUE
-#' ))
-#' params <- get_tidy_parameter(cn_tally_M$components)
-#' p4 <- show_sig_profile(sig,
-#'   mode = "copynumber",
-#'   method = "M", normalize = "column",
-#'   params = params, y_expand = 2
-#' )
-#' p4
-#'
 #' # Visualize rearrangement signatures
 #' s <- get_sig_db("RS_Nik_lab")
 #' ss <- s$db[, 1:3]
 #' colnames(ss) <- c("Sig1", "Sig2", "Sig3")
-#' p5 <- show_sig_profile(ss, mode = "RS", style = "cosmic")
-#' p5
+#' p3 <- show_sig_profile(ss, mode = "RS", style = "cosmic")
+#' p3
 #' @testexamples
 #' expect_s3_class(p1, "ggplot")
 #' expect_s3_class(p11, "ggplot")
 #' expect_s3_class(p2, "ggplot")
 #' expect_s3_class(p3, "ggplot")
-#' expect_s3_class(p4, "ggplot")
-#' expect_s3_class(p5, "ggplot")
 show_sig_profile <- function(Signature,
                              mode = c("SBS", "copynumber", "DBS", "ID", "RS"),
                              method = "Wang",
@@ -183,7 +152,7 @@ show_sig_profile <- function(Signature,
   mode <- match.arg(mode)
   method <- match.arg(
     method,
-    choices = c("Macintyre", "M", "Wang", "W", "Tao & Wang", "T", "X", "S")
+    choices = c("Wang", "W", "Tao & Wang", "T", "X", "S")
   )
   normalize <- match.arg(normalize)
   style <- match.arg(style)
@@ -234,36 +203,7 @@ show_sig_profile <- function(Signature,
   }
 
   if (mode == "copynumber") {
-    if (startsWith(method, "M")) {
-      mat$base <- sub("\\d+$", "", mat$context)
-      if (!"copynumber" %in% mat$base) {
-        send_stop("You may choose wrong 'method' option, please try method = 'W' or 'T'.")
-      }
-      mat <- tidyr::gather(mat, class, signature, -c("context", "base"))
-
-      ## Use same label as "Wang" method.
-      mp <- c("BP10MB", "BPArm", "CN", "CNCP", "OsCN", "SS")
-      names(mp) <- c(
-        "bp10MB", "bpchrarm",
-        "copynumber", "changepoint",
-        "osCN", "segsize"
-      )
-
-      mat <- mat %>%
-        dplyr::mutate(
-          base = mp[.data$base],
-          context = paste0(.data$base, "[", sub(".*[^0-9]+(\\d+$)", "\\1", .data$context), "]"),
-          base = factor(.data$base, levels = as.character(mp))
-        ) %>%
-        dplyr::arrange(.data$base)
-
-      mat <- dplyr::mutate(mat,
-        context = factor(.data$context,
-          levels = unique(mat[["context"]])
-        ),
-        class = factor(class, levels = colnames(Sig))
-      )
-    } else if (startsWith(method, "W")) {
+    if (startsWith(method, "W")) {
       mat$base <- sub("\\[.*\\]$", "", mat$context)
       if (!"CN" %in% mat$base) {
         send_stop("You may choose wrong 'method' option, please try method = 'M' or 'T'.")
@@ -636,38 +576,7 @@ show_sig_profile <- function(Signature,
     }
   }
 
-
-  if (mode == "copynumber" & startsWith(method, "M")) {
-    if (!is.null(params)) {
-      params <- dplyr::mutate(params,
-        feature = mp[.data$feature],
-        components = paste0(.data$feature, "[", sub(".*[^0-9]+(\\d+$)", "\\1", .data$components), "]")
-      )
-      params$class <- factor(levels(mat[["class"]])[1], levels = levels(mat[["class"]]))
-      p <- p + geom_text(aes(
-        x = .data$components, y = Inf,
-        label = ifelse(.data$dist == "norm",
-          paste0(
-            " \u03BC=", signif(.data$mean, digits),
-            ifelse(rep(show_cv, length(.data$cv)), paste0("; cv=", signif(.data$cv, digits)), "")
-          ),
-          paste0(
-            " \u03BB=", signif(.data$mean, digits),
-            ifelse(rep(show_cv, length(.data$cv)), paste0("; cv=", signif(.data$cv, digits)), "")
-          )
-        )
-      ),
-      data = params,
-      size = params_label_size,
-      angle = params_label_angle,
-      hjust = 0, vjust = 0.5
-      ) +
-        coord_cartesian(clip = "off")
-    }
-    p <- p + facet_grid(class ~ ., scales = "free", space = free_space)
-  } else {
-    p <- p + facet_grid(class ~ base, scales = "free", space = free_space)
-  }
+  p <- p + facet_grid(class ~ base, scales = "free", space = free_space)
 
   p <- p + scale_y_continuous(
     labels = scales::number_format(
